@@ -47,6 +47,19 @@ class Signals(Enum):
     TaskRemoved = "task.removed"
     TaskUpdated = "task.updated"
 
+    # Playtime lifecycle signals
+    ProgramStarted = "Playtime.program_started"
+
+    # ProgramFinished data payload:
+    ProgramFinished = "Playtime.program_finished"
+
+    # Eagle analysis signals
+    EagleStep = "Eagle.step"  # data(Result): msg(str)
+    EagleFinished = "Eagle.finished"  # data(Result): results(dict)
+
+    # Dynamic launcher portal
+    DesktopEntryCreated = "DesktopEntry.created"
+
 
 class Status(Enum):
     RUNNING = "running"
